==> haskell-warp-3.2.3-11-armv7h.pkg.tar.xz: usr/share/haskell/haskell-warp/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.3
id: warp-3.2.3-6de819de378ae4c57281b63b66004254
key: warp_Lv6uiPhbsbh4FmLZhRPGRI
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.ReadInt
                Network.Wai.Handler.Warp.Recv Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Paths_warp Network.Wai.Handler.Warp.MultiMap
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-3.2.3
hs-libraries: HSwarp-3.2.3-Lv6uiPhbsbh4FmLZhRPGRI
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    http-date-0.0.6.1-757f4a31bc2dcd5d0b4e75509958696c
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    http2-1.5.4-82dccce60697e4ed1d56153dae3e45f1
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    simple-sendfile-0.2.21-b4189a70d5e750749d989e840422f185
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.2.4-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-warp/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.4
id: warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
key: warp_3URFxxGLnVl62M4QPEPtbo
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.ReadInt
                Network.Wai.Handler.Warp.Recv Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Some
                Network.Wai.Handler.Warp.Timeout Network.Wai.Handler.Warp.Types
                Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-3.2.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-3.2.4
hs-libraries: HSwarp-3.2.4-3URFxxGLnVl62M4QPEPtbo
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    http-date-0.0.6.1-757f4a31bc2dcd5d0b4e75509958696c
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    http2-1.5.4-82dccce60697e4ed1d56153dae3e45f1
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    simple-sendfile-0.2.21-b4189a70d5e750749d989e840422f185
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
